"""Utility functions and helpers."""
from .text_preprocessing import pre_tokenize, normalize_text
from .gradient_utils import (
    compute_gradient_norms,
    compute_layer_gradient_norms,
    check_vanishing_gradients,
    check_exploding_gradients,
    gradient_health_check,
    GradientMonitor,
)

__all__ = [
    "pre_tokenize", 
    "normalize_text",
    "compute_gradient_norms",
    "compute_layer_gradient_norms",
    "check_vanishing_gradients",
    "check_exploding_gradients",
    "gradient_health_check",
    "GradientMonitor",
]